CREATE TABLE table_company (
  company_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  company_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(company_id)
)
ENGINE=INNODB;

INSERT INTO table_company VALUES (1, 'na');
INSERT INTO table_company VALUES (10, 'XQual');
INSERT INTO table_company VALUES (11, 'My Company');

CREATE TABLE table_filter (
  filter_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  filter_description TEXT CHARACTER SET utf8 NULL,
  filter_data LONGTEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(filter_id)
)
ENGINE=INNODB;

CREATE TABLE table_version (
  version_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  version_number INTEGER UNSIGNED NULL,
  PRIMARY KEY(version_id)
)
ENGINE=INNODB;

CREATE TABLE table_category (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  category_envDesc TEXT CHARACTER SET utf8,
  category_jarName VARCHAR(64) CHARACTER SET utf8 NULL,
  PRIMARY KEY(category_id)
)
ENGINE=INNODB;

INSERT INTO table_category VALUES (1, 'na', 'na', 'na');
INSERT INTO table_category VALUES (10, 'Manual Tests', "This is a category dedicated to manual tests (launcher set to [b]tabular_manual.jar[/b])", "tabular_manual.jar");
INSERT INTO table_category VALUES (11, 'Automated Tests (i.e. JUnit)', "This is a category dedicated to automated tests (i.e. JUnit tests in this case as the launcher is set to [b]junit.jar[/b])", "junit.jar");

CREATE TABLE table_category_stat (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  date_submitted DATETIME NULL,
  nb_tests INTEGER UNSIGNED NOT NULL DEFAULT 0,
  nb_tests_developed INTEGER UNSIGNED NOT NULL DEFAULT 0,
  nb_tests_authored INTEGER UNSIGNED NOT NULL DEFAULT 0,
  nb_cases INTEGER UNSIGNED NOT NULL DEFAULT 0,
  nb_cases_developed INTEGER UNSIGNED NOT NULL DEFAULT 0,
  nb_cases_authored INTEGER UNSIGNED NOT NULL DEFAULT 0,
  INDEX category_stat_IK_1(category_id),
  FOREIGN KEY (category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_attr_string (
  attr_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_string_name VARCHAR(60) CHARACTER SET utf8 NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  attr_string_normal_values VARCHAR(4096) CHARACTER SET utf8,
  PRIMARY KEY(attr_string_id),
  UNIQUE KEY attr_string_UK_1 (attr_string_name)
)
ENGINE=INNODB;

CREATE TABLE table_attr_integer (
  attr_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_integer_name VARCHAR(60) CHARACTER SET utf8 NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  attr_integer_normal_values VARCHAR(4096) CHARACTER SET utf8,
  PRIMARY KEY(attr_integer_id),
  UNIQUE KEY attr_integer_UK_1 (attr_integer_name)
)
ENGINE=INNODB;

CREATE TABLE table_attr_boolean (
  attr_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_boolean_name VARCHAR(60) CHARACTER SET utf8 NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_boolean_id),
  UNIQUE KEY attr_boolean_UK_1 (attr_boolean_name)
)
ENGINE=INNODB;

CREATE TABLE table_folder (
  folder_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id_2 INTEGER UNSIGNED NULL,
  folder_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  company_id INTEGER UNSIGNED NOT NULL,
  folder_description TEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(folder_id),
  INDEX folder_IK_1(folder_id_2),
  INDEX folder_IK_2(category_id),
  INDEX folder_IK_3(company_id),
  FOREIGN KEY (folder_id_2)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (company_id)
    REFERENCES table_company(company_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

INSERT INTO table_folder VALUES (1,   1, 'na', 1, 1, NULL); #user
INSERT INTO table_folder VALUES (2,   2, 'na', 1, 1, NULL); #sut
INSERT INTO table_folder VALUES (3,   3, 'na', 1, 1, NULL); #req
INSERT INTO table_folder VALUES (4,   4, 'na', 1, 1, NULL); #spec
INSERT INTO table_folder VALUES (5,   5, 'na', 1, 1, NULL); #test
INSERT INTO table_folder VALUES (6,   6, 'na', 1, 1, NULL); #campaign
INSERT INTO table_folder VALUES (7,   7, 'na', 1, 1, NULL); #defect
INSERT INTO table_folder VALUES (8,   8, 'na', 1, 1, NULL); #agent
INSERT INTO table_folder VALUES (9,   9, 'na', 1, 1, NULL); #project
INSERT INTO table_folder VALUES (10, 10, 'na', 1, 1, NULL); #task
INSERT INTO table_folder VALUES (11, 11, 'na', 1, 1, NULL); #documents

INSERT INTO table_folder VALUES (29, 1, 'Administration',     1,    10, "This is a folder containing some administrative users"); #xqual
INSERT INTO table_folder VALUES (30, 6, 'Manual',             1,    10, "This is a folder containing only manual campaigns (when the test operator run a test directly from the test tree)");
INSERT INTO table_folder VALUES (31, 1, 'My Users',           1,    11, "This is a folder containing some users"); #mycompany
INSERT INTO table_folder VALUES (32, 2, 'My SUTs',            1,    11, "This is a folder containing some SUTs"); #mycompany
INSERT INTO table_folder VALUES (33, 3, 'My Requirements',    1,    10, "This is a folder containing some requirements");
INSERT INTO table_folder VALUES (34, 4, 'My Specifications',  1,    10, "This is a folder containing some specifications");
INSERT INTO table_folder VALUES (35, 5, 'My Manual Tests',    10,   10, "This is a folder containing some manual tests");
INSERT INTO table_folder VALUES (36, 5, 'My Automated Tests', 11,   10, "This is a folder containing some automated tests");
INSERT INTO table_folder VALUES (37, 7, 'My Issues',          1,    10, "This is a folder containing some issues");
INSERT INTO table_folder VALUES (38, 9, 'My Projects',        1,    10, "This is a folder containing some projects");
INSERT INTO table_folder VALUES (39, 11, 'My Documents',      1,    10, "This is a folder containing some documents");

CREATE TABLE table_project (
  project_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  project_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  project_description TEXT CHARACTER SET utf8 NULL,
  focus_ratio TINYINT UNSIGNED NOT NULL DEFAULT 80,
  PRIMARY KEY(project_id),
  INDEX project_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

INSERT INTO table_project VALUES (1, 1, 'na', 'na', 80);

ALTER TABLE table_folder ADD project_id INTEGER UNSIGNED NOT NULL DEFAULT 1 AFTER company_id;
ALTER TABLE table_folder ADD INDEX folder_IK_4(project_id);
ALTER TABLE table_folder ADD FOREIGN KEY (project_id) 
    REFERENCES table_project(project_id)
      ON DELETE CASCADE 
      ON UPDATE NO ACTION;

CREATE TABLE table_sut (
  sut_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(sut_id),
  INDEX sut_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sut_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_id INTEGER UNSIGNED NOT NULL,
  sut_version VARCHAR(64) CHARACTER SET utf8 NULL,
  date_submitted DATETIME NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  coverage TINYINT UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(data_id),
  UNIQUE KEY sut_data_UK_1(sut_id, revision),
  INDEX sut_data_IK_1(sut_id),
  FOREIGN KEY (sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
) ENGINE=INNODB;
											       
													       
CREATE TABLE table_agent (
  agent_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  agent_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  agent_os VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  agent_description TEXT CHARACTER SET utf8 NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(agent_id),
  INDEX agent_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_country (
  country_id CHAR(2) NOT NULL,
  country_name VARCHAR(80) NOT NULL,
  PRIMARY KEY(country_id)
)
ENGINE=INNODB DEFAULT CHARSET=latin1;

INSERT INTO table_country VALUES ('US','United States');

CREATE TABLE table_userprofile (
  userprofile_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  userprofile_name VARCHAR(128) NOT NULL,
  rights TEXT NULL,
  INDEX userprofile_IK_1(userprofile_id)
)
ENGINE=INNODB;

CREATE TABLE table_usergroup (
  usergroup_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  usergroup_name VARCHAR(128) NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(usergroup_id),
  INDEX usergroup_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION     
)
ENGINE=INNODB;

CREATE TABLE table_user (
  user_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_name VARCHAR(128) NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  user_password TEXT NULL,
  user_local VARCHAR(5) DEFAULT 'en_US' NOT NULL,
  user_email VARCHAR(50) DEFAULT '' NOT NULL,
  user_enabled BOOL NOT NULL DEFAULT 1,
  country_id CHAR(2) CHARACTER SET latin1 NOT NULL DEFAULT 'US',
  userprofile_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(user_id),
  INDEX user_IK_1(folder_id),
  INDEX user_IK_2(country_id),
  INDEX user_IK_3(userprofile_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (country_id)
    REFERENCES table_country(country_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (userprofile_id)
    REFERENCES table_userprofile(userprofile_id)
      ON DELETE SET NULL
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_def_generic (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  external_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(defect_id),
  INDEX def_generic_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_def_int (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  defect_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  reporter INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(defect_id),
  INDEX def_int_IK_1(folder_id),
  INDEX def_int_IK_2(reporter),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (reporter)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_def_int_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  defect_id INTEGER UNSIGNED NOT NULL,
  defect_description TEXT CHARACTER SET utf8 NULL,
  priority TINYINT NOT NULL,
  severity TINYINT NOT NULL,
  status TINYINT NOT NULL,
  step_to_reproduce TEXT CHARACTER SET utf8,
  reproducibility TINYINT DEFAULT 1,
  platform_id INTEGER UNSIGNED NOT NULL DEFAULT 999,
  os_id INTEGER UNSIGNED NOT NULL DEFAULT 999,
  fix_target_date DATETIME NULL,
  fix_target_version VARCHAR(32) CHARACTER SET utf8 NULL,
  completion_percentage TINYINT NOT NULL DEFAULT 0,
  fix_type TINYINT NULL,
  fix_description TEXT CHARACTER SET utf8 NULL,
  fix_patches VARCHAR(64) CHARACTER SET utf8 NULL,
  date_submitted DATETIME NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  UNIQUE KEY def_int_data_UK_1(defect_id, revision),
  INDEX def_int_data_IK_1(defect_id),
  FOREIGN KEY (defect_id)
    REFERENCES table_def_int(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
) ENGINE=INNODB;

CREATE TABLE table_def_int_assigned_to (
  defect_id INTEGER UNSIGNED NOT NULL,
  assigned_to INTEGER UNSIGNED NOT NULL,
  UNIQUE KEY def_int_assigned_to_UK_1(defect_id, assigned_to),
  INDEX def_int_assigned_to_IK_1(defect_id),
  INDEX def_int_assigned_to_IK_2(assigned_to),
  FOREIGN KEY (defect_id)
    REFERENCES table_def_int(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (assigned_to)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_req_int (
  requirement_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  requirement_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(requirement_id),
  INDEX req_int_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_camp (
  campaign_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  campaign_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  campaign_description TEXT CHARACTER SET utf8 NULL,
  parallel_execution BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(campaign_id),
  INDEX camp_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_spec (
  specification_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  specification_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(specification_id),
  INDEX spec_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test (
  test_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  author_id INTEGER UNSIGNED NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  test_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  test_estimatedTime BIGINT UNSIGNED NOT NULL DEFAULT 0,
  developer_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(test_id),
  INDEX test_IK_1(folder_id),
  INDEX test_IK_2(author_id),
  INDEX test_IK_3(developer_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (developer_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  test_description LONGTEXT CHARACTER SET utf8,
  test_priority INTEGER UNSIGNED NOT NULL DEFAULT 99,
  test_canonicalPath VARCHAR(255),
  test_prerequisites TEXT CHARACTER SET utf8,
  additional_info TEXT CHARACTER SET utf8,
  date_submitted DATETIME NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  UNIQUE KEY test_data_UK_1(test_id, revision),
  INDEX test_data_IK_1(test_id),
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_req_spec (
  requirement_id INTEGER UNSIGNED NOT NULL,
  specification_id INTEGER UNSIGNED NOT NULL,
  INDEX req_spec_IK_1(requirement_id),
  INDEX req_spec_IK_2(specification_id),
  FOREIGN KEY (specification_id)
    REFERENCES table_spec(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_monitoring_conf (
  monitoring_conf_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  monitoring_conf_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  monitoring_conf_data TEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(monitoring_conf_id)
)
ENGINE=INNODB;

CREATE TABLE table_sch (
  schedule_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  schedule_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  schedule_description TEXT CHARACTER SET utf8 NULL,
  schedule_nextStartDate DATETIME NULL,
  campaign_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  schedule_enabled BOOL NOT NULL DEFAULT 1,
  schedule_every TEXT NOT NULL,
  schedule_at TEXT NULL,
  sut_id INTEGER UNSIGNED NOT NULL,
  on_parent_failed TINYINT NOT NULL DEFAULT 3,
  on_parent_unknown TINYINT NOT NULL DEFAULT 1,
  monitoring_id INTEGER UNSIGNED,
  monitoring_conf_id INTEGER UNSIGNED,
  pick TINYINT UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(schedule_id),
  INDEX sch_IK_1(campaign_id),
  INDEX sch_IK_2(user_id),
  INDEX sch_IK_3(sut_id),
  INDEX sch_IK_4(monitoring_id),
  INDEX sch_IK_5(monitoring_conf_id),
  FOREIGN KEY (campaign_id)
    REFERENCES table_camp(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (monitoring_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (monitoring_conf_id)
    REFERENCES table_monitoring_conf(monitoring_conf_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sch_agent ( 
  schedule_id INTEGER UNSIGNED NOT NULL, 
  agent_id INTEGER UNSIGNED NOT NULL, 
  nb_instance INTEGER UNSIGNED NOT NULL DEFAULT 1,
  sync_type TINYINT UNSIGNED NOT NULL DEFAULT 0,
  UNIQUE KEY sch_agent_UK_1(schedule_id, agent_id), 
  INDEX sch_agent_IK_1(schedule_id), 
  INDEX sch_agent_IK_2(agent_id), 
  FOREIGN KEY (schedule_id) 
    REFERENCES table_sch(schedule_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (agent_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB;

CREATE TABLE table_sess (
  campaign_session_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  campaign_id INTEGER UNSIGNED,
  sut_id INTEGER UNSIGNED NOT NULL,
  campaign_session_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  campaign_session_startDate DATETIME NULL,
  campaign_session_stopDate DATETIME NULL,
  campaign_session_status INTEGER UNSIGNED NOT NULL DEFAULT 1,
  schedule_id INTEGER UNSIGNED,
  introduction TEXT CHARACTER SET utf8 NULL,
  conclusion TEXT CHARACTER SET utf8 NULL,
  on_parent_failed TINYINT NOT NULL DEFAULT 3,
  on_parent_unknown TINYINT NOT NULL DEFAULT 1,
  monitoring_id INTEGER UNSIGNED,
  monitoring_conf_id INTEGER UNSIGNED,
  pick TINYINT UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(campaign_session_id),
  INDEX sess_IK_1(sut_id),
  INDEX sess_IK_2(campaign_id),
  INDEX sess_IK_3(user_id),
  INDEX sess_IK_4(schedule_id),
  INDEX sess_IK_5(monitoring_id),
  INDEX sess_IK_6(monitoring_conf_id),
  FOREIGN KEY (sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (campaign_id)
    REFERENCES table_camp(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (monitoring_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (monitoring_conf_id)
    REFERENCES table_monitoring_conf(monitoring_conf_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION      
)
ENGINE=INNODB;

CREATE TABLE table_instance (
  instance_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  campaign_session_id INTEGER UNSIGNED NOT NULL, 
  agent_id INTEGER UNSIGNED NOT NULL, 
  instance_index INTEGER UNSIGNED NOT NULL DEFAULT 0, 
  sync_type TINYINT UNSIGNED NOT NULL DEFAULT 0,  
  PRIMARY KEY(instance_id),
  UNIQUE KEY instance_UK_1(campaign_session_id, agent_id, instance_index), 
  INDEX instance_IK_1(campaign_session_id), 
  INDEX instance_IK_2(agent_id), 
  INDEX instance_IK_3(instance_index), 
  INDEX instance_IK_4(sync_type), 
  FOREIGN KEY (campaign_session_id) 
    REFERENCES table_sess(campaign_session_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (agent_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB;

CREATE TABLE table_sync (
  instance_id INTEGER UNSIGNED NOT NULL, 
  category_id INTEGER UNSIGNED NOT NULL, 
  sync_id INTEGER UNSIGNED NOT NULL DEFAULT 0,
  UNIQUE KEY sync_UK_1(instance_id, category_id, sync_id),
  INDEX sync_IK_1(instance_id), 
  INDEX sync_IK_2(category_id), 
  INDEX sync_IK_3(sync_id),
  FOREIGN KEY (instance_id) 
    REFERENCES table_instance(instance_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (category_id) 
    REFERENCES table_category(category_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB; 
  
CREATE TABLE table_case (
  case_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  testcase_index INTEGER UNSIGNED NOT NULL,
  testcase_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  testcase_dev_completed BOOL NOT NULL DEFAULT 0,
  testcase_auth_completed BOOL NOT NULL DEFAULT 1,
  PRIMARY KEY(case_id),
  UNIQUE KEY case_UK_1(test_id, testcase_index, testcase_name),
  INDEX case_IK_1(test_id),
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_case_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_steps TEXT CHARACTER SET utf8 NULL,
  testcase_description TEXT CHARACTER SET utf8 NULL,
  testcase_useDescAsTestplan BOOL NOT NULL DEFAULT 0,
  additional_info TEXT CHARACTER SET utf8,
  date_submitted DATETIME NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id)
)
ENGINE=INNODB;


CREATE TABLE table_test_dependencies (
  test_id INTEGER UNSIGNED NOT NULL,
  dependsFromTest_id INTEGER UNSIGNED NOT NULL,
  INDEX test_dependencies_IK_1(test_id),
  INDEX test_dependencies_IK_2(dependsFromTest_id),
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (dependsFromTest_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION      
)
ENGINE=INNODB;

CREATE TABLE table_test_attr_boolean (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  test_attr_boolean_value BOOL NOT NULL DEFAULT 0,
  INDEX test_attr_boolean_IK_1(attr_boolean_id),
  INDEX test_attr_boolean_IK_2(test_id),
  FOREIGN KEY (attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test_attr_string (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  test_attr_string_value TEXT CHARACTER SET utf8,
  INDEX test_attr_string_IK_1(attr_string_id),
  INDEX test_attr_string_IK_2(test_id),
  FOREIGN KEY (attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test_attr_integer (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  test_attr_integer_value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX test_attr_integer_IK_1(attr_integer_id),
  INDEX test_attr_integer_IK_2(test_id),
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_spec_test (
  specification_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX spec_test_IK_1(test_id),
  INDEX spec_test_IK_2(specification_id),
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (specification_id)
    REFERENCES table_spec(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test_camp (
  campaign_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  position INTEGER UNSIGNED NOT NULL DEFAULT 0,
  INDEX test_camp_IK_1(test_id),
  INDEX test_camp_IK_2(campaign_id),
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (campaign_id)
    REFERENCES table_camp(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_case_exec (
  testcase_exec_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  case_id INTEGER UNSIGNED NOT NULL,
  testcase_exec_result INTEGER UNSIGNED NOT NULL,
  testcase_exec_message MEDIUMTEXT CHARACTER SET utf8 NULL,
  timestamp BIGINT UNSIGNED NOT NULL DEFAULT 0,
  instance_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(testcase_exec_id),
  UNIQUE KEY case_exec_UK_1 (campaign_session_id, case_id, instance_id),
  INDEX case_exec_IK_1(case_id),
  INDEX case_exec_IK_2(campaign_session_id),
  INDEX case_exec_IK_3(instance_id),
  FOREIGN KEY (case_id)
    REFERENCES table_case(case_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (instance_id)
    REFERENCES table_instance(instance_id)
      ON DELETE CASCADE 
      ON UPDATE NO ACTION      
)
ENGINE=INNODB;

CREATE TABLE table_test_exec (
  test_exec_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  test_exec_result INTEGER UNSIGNED NOT NULL,
  timestamp BIGINT UNSIGNED NOT NULL DEFAULT 0,
  instance_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(test_exec_id),
  UNIQUE KEY test_exec_UK_1 (campaign_session_id, test_id, instance_id),
  INDEX test_exec_IK_1(test_id),
  INDEX test_exec_IK_2(campaign_session_id),
  INDEX test_exec_IK_3(instance_id),
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (instance_id)
    REFERENCES table_instance(instance_id)
      ON DELETE CASCADE 
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test_exec_def (
  defect_id INTEGER UNSIGNED NOT NULL,
  test_exec_id INTEGER UNSIGNED NOT NULL,
  INDEX test_exec_def_IK_1(test_exec_id),
  UNIQUE KEY test_exec_def_UK_1 (defect_id, test_exec_id),
  FOREIGN KEY (test_exec_id)
    REFERENCES table_test_exec(test_exec_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sess_ccemails (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX sess_ccemails_IK_1(campaign_session_id),
  INDEX sess_ccemails_IK_2(user_id),
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sch_ccemails (
  schedule_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX sch_ccemails_IK_1(schedule_id),
  INDEX sch_ccemails_IK_2(user_id),
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_change (
  type TINYINT NOT NULL,
  id INTEGER UNSIGNED NOT NULL,
  date_submitted DATETIME NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  action TINYINT NOT NULL,
  information VARCHAR(255) CHARACTER SET utf8,
  INDEX change_IK_1(user_id),
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_def_stat (
  entry_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  database_type TINYINT NOT NULL,
  container_type TINYINT NOT NULL,
  type TINYINT NOT NULL,
  container VARCHAR(255) CHARACTER SET utf8 NULL,
  date_submitted DATETIME NULL,
  stat MEDIUMTEXT CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(entry_id)
)
ENGINE=INNODB;

CREATE TABLE table_platform (
  platform_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  platform_name VARCHAR(32) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(platform_id)
)
ENGINE=INNODB;

CREATE TABLE table_os (
  os_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  os_name VARCHAR(32) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(os_id)
)
ENGINE=INNODB;

CREATE TABLE table_def_int_sut (
  type TINYINT NOT NULL,
  defect_id INTEGER UNSIGNED NOT NULL,
  sut_id INTEGER UNSIGNED NOT NULL,
  UNIQUE KEY def_int_sut_UK_1 (type, defect_id, sut_id),
  INDEX def_int_sut_IK_1(defect_id),
  INDEX def_int_sut_IK_2(sut_id),
  FOREIGN KEY (defect_id)
    REFERENCES table_def_int(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_conf (
  conf_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  jar_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  conf_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  conf_data TEXT CHARACTER SET utf8 NULL,
  INDEX conf_IK_1(conf_id),
  UNIQUE KEY conf_UK_1(jar_name, conf_name)
)
ENGINE=INNODB;

CREATE TABLE table_sess_conf (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  conf_id INTEGER UNSIGNED NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  INDEX sess_conf_IK_1(campaign_session_id),
  INDEX sess_conf_IK_2(conf_id),
  INDEX sess_conf_IK_3(category_id),
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (conf_id)
    REFERENCES table_conf(conf_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sch_conf (
  schedule_id INTEGER UNSIGNED NOT NULL,
  conf_id INTEGER UNSIGNED NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  INDEX sch_conf_IK_1(schedule_id),
  INDEX sch_conf_IK_2(conf_id),
  INDEX sch_conf_IK_3(category_id),
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (conf_id)
    REFERENCES table_conf(conf_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_task (
  task_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  task_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  task_description TEXT CHARACTER SET utf8 NULL,
  priority TINYINT NOT NULL,
  estimated DECIMAL(3,1) NOT NULL DEFAULT 1.0,
  PRIMARY KEY(task_id),
  INDEX task_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;



CREATE TABLE table_sprint (
  sprint_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sprint_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  sprint_description TEXT CHARACTER SET utf8 NULL,
  status TINYINT NOT NULL,
  start_date DATETIME NULL,
  stop_date DATETIME NULL,
  project_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(sprint_id),
  INDEX sprint_IK_1(project_id),
  FOREIGN KEY (project_id)
    REFERENCES table_project(project_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sprint_task (
  sprint_id INTEGER UNSIGNED NOT NULL,
  task_id INTEGER UNSIGNED NOT NULL,
  progress TINYINT UNSIGNED NOT NULL DEFAULT 0,
  assigned_to INTEGER UNSIGNED NULL,
  INDEX sprint_task_IK_1(sprint_id),
  INDEX sprint_task_IK_2(task_id),
  INDEX sprint_task_IK_3(assigned_to),
  FOREIGN KEY (sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (task_id)
    REFERENCES table_task(task_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (assigned_to)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION      
)
ENGINE=INNODB;

CREATE TABLE table_sprint_developer (
  sprint_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  availability TINYINT UNSIGNED NOT NULL DEFAULT 0,
  INDEX sprint_developer_IK_1(sprint_id),
  INDEX sprint_developer_IK_2(user_id),
  FOREIGN KEY (sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sprint_stat (
  sprint_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  date_submitted DATETIME NULL,
  stat MEDIUMTEXT CHARACTER SET utf8 NOT NULL,
  INDEX sprint_stat_IK_1(sprint_id),
  FOREIGN KEY (sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sess_attr_string (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8,
  INDEX sess_attr_string_IK_1(campaign_session_id),
  INDEX sess_attr_string_IK_2(test_id),
  INDEX sess_attr_string_IK_3(attr_string_id),
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sess_attr_boolean (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  value BOOL NOT NULL DEFAULT 0,
  INDEX sess_attr_boolean_IK_1(campaign_session_id),
  INDEX sess_attr_boolean_IK_2(test_id),
  INDEX sess_attr_boolean_IK_3(attr_boolean_id),
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sess_attr_integer (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX sess_attr_integer_IK_1(campaign_session_id),
  INDEX sess_attr_integer_IK_2(test_id),
  INDEX sess_attr_integer_IK_3(attr_integer_id),
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_absence_type (
  absence_type_id TINYINT UNSIGNED NOT NULL AUTO_INCREMENT,
  absence_type_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(absence_type_id)
)
ENGINE=INNODB;

CREATE TABLE table_absence (
  absence_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  type TINYINT NOT NULL DEFAULT 10,
  start_date DATETIME NULL,
  stop_date DATETIME NULL,
  comments TEXT CHARACTER SET utf8 NULL,
  status TINYINT NOT NULL DEFAULT 10,
  PRIMARY KEY(absence_id),
  INDEX absence_IK_1(user_id),
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_holiday (
  holiday_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  country_id CHAR(2) NOT NULL,
  start_date DATETIME NULL,
  stop_date DATETIME NULL,
  comments TEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(holiday_id),
  INDEX holiday_IK_1(country_id),
  FOREIGN KEY (country_id)
    REFERENCES table_country(country_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB DEFAULT CHARSET=latin1;

CREATE TABLE table_weekend (
  weekend_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  country_id CHAR(2) NOT NULL,
  days VARCHAR(14) CHARACTER SET utf8 ,
  PRIMARY KEY(weekend_id),
  INDEX weekend_IK_1(country_id),
  FOREIGN KEY (country_id)
    REFERENCES table_country(country_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB DEFAULT CHARSET=latin1;

CREATE TABLE table_sut_req (
  sut_id INTEGER UNSIGNED NOT NULL,
  requirement_id INTEGER UNSIGNED NOT NULL,
  INDEX sut_req_IK_1(sut_id),
  INDEX sut_req_IK_2(requirement_id),
  FOREIGN KEY (sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_case_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  case_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX case_attach_IK_1(locked_by),
  INDEX case_attach_IK_2(case_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (case_id)
    REFERENCES table_case(case_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_case_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX case_attach_data_IK_1(attachment_id),
  INDEX case_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_case_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX test_attach_IK_1(locked_by),
  INDEX test_attach_IK_2(test_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX test_attach_data_IK_1(attachment_id),
  INDEX test_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_test_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_folder_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX folder_attach_IK_1(locked_by),
  INDEX folder_attach_IK_2(folder_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_folder_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX folder_attach_data_IK_1(attachment_id),
  INDEX folder_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_folder_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_category_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX category_attach_IK_1(locked_by),
  INDEX category_attach_IK_2(category_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_category_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX category_attach_data_IK_1(attachment_id),
  INDEX category_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_category_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_case_exec_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_exec_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX case_exec_attach_IK_1(locked_by),
  INDEX case_exec_attach_IK_2(testcase_exec_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (testcase_exec_id)
    REFERENCES table_case_exec(testcase_exec_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_case_exec_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX case_exec_attach_data_IK_1(attachment_id),
  INDEX case_exec_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_case_exec_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_def_int_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  defect_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX def_int_attach_IK_1(locked_by),
  INDEX def_int_attach_IK_2(defect_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (defect_id)
    REFERENCES table_def_int(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_def_int_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX def_int_attach_data_IK_1(attachment_id),
  INDEX def_int_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_def_int_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sess_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX sess_attach_IK_1(locked_by),
  INDEX sess_attach_IK_2(campaign_session_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sess_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX sess_attach_data_IK_1(attachment_id),
  INDEX sess_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_sess_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_req_int_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  requirement_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX req_int_attach_IK_1(locked_by),
  INDEX req_int_attach_IK_2(requirement_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (requirement_id)
    REFERENCES table_req_int(requirement_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_req_int_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX req_int_attach_data_IK_1(attachment_id),
  INDEX req_int_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_req_int_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_spec_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  specification_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX spec_attach_IK_1(locked_by),
  INDEX spec_attach_IK_2(specification_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (specification_id)
    REFERENCES table_spec(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_spec_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX spec_attach_data_IK_1(attachment_id),
  INDEX spec_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_spec_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_monitor ( 
  monitor_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  campaign_session_id INTEGER UNSIGNED NOT NULL, 
  monitored_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(monitor_id),
  UNIQUE KEY monitor_UK_1(campaign_session_id, monitored_id), 
  INDEX monitor_IK_1(campaign_session_id), 
  INDEX monitor_IK_2(monitored_id), 
  FOREIGN KEY (campaign_session_id) 
    REFERENCES table_sess(campaign_session_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (monitored_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB; 

CREATE TABLE table_monitored_results ( 
  monitor_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  timestamp BIGINT UNSIGNED NOT NULL DEFAULT 0,
  class VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  subclass VARCHAR(128) CHARACTER SET utf8,
  value INTEGER NOT NULL DEFAULT 0, 
  INDEX monitored_results_IK_1(monitor_id),
  FOREIGN KEY (monitor_id) 
    REFERENCES table_monitor(monitor_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION     
)
ENGINE=INNODB;        

CREATE TABLE table_sch_monitored ( 
  schedule_id INTEGER UNSIGNED NOT NULL, 
  monitored_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY sch_monitored_UK_1(schedule_id, monitored_id), 
  INDEX sch_monitored_IK_1(schedule_id), 
  INDEX sch_monitored_IK_2(monitored_id), 
  FOREIGN KEY (schedule_id) 
    REFERENCES table_sch(schedule_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (monitored_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB;

CREATE TABLE table_req_int_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  requirement_id INTEGER UNSIGNED NOT NULL, 
  requirement_description TEXT CHARACTER SET utf8 NULL, 
  type SMALLINT NOT NULL DEFAULT 10, 
  priority TINYINT NOT NULL DEFAULT 20, 
  status TINYINT NOT NULL DEFAULT 30, 
  date_submitted DATETIME NULL, 
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1, 
  coverage TINYINT UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(data_id), 
  UNIQUE KEY req_int_data_UK_1(requirement_id, revision), 
  INDEX req_int_data_IK_1(requirement_id), 
  FOREIGN KEY (requirement_id) 
    REFERENCES table_req_int(requirement_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
) ENGINE=INNODB;


CREATE TABLE table_spec_data ( 
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  specification_id INTEGER UNSIGNED NOT NULL, 
  specification_isFormal BOOL NOT NULL DEFAULT 0, 
  specification_description TEXT CHARACTER SET utf8 NULL, 
  priority TINYINT NOT NULL DEFAULT 20, 
  status TINYINT NOT NULL DEFAULT 30, 
  date_submitted DATETIME NULL, 
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1, 
  coverage TINYINT UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(data_id), 
  UNIQUE KEY spec_data_UK_1(specification_id, revision), 
  INDEX spec_data_IK_1(specification_id), 
  FOREIGN KEY (specification_id) 
    REFERENCES table_spec(specification_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
) ENGINE=INNODB;

CREATE TABLE table_project_manager (
  project_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  UNIQUE KEY project_manager_UK_1(project_id, user_id),
  INDEX project_manager_IK_1(project_id),
  INDEX project_manager_IK_2(user_id),
  FOREIGN KEY (project_id)
    REFERENCES table_project(project_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_test_url (
  url_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_data_id INTEGER UNSIGNED NOT NULL,
  url VARCHAR(384) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(url_id), 
  INDEX test_url_IK_1(test_data_id),
  FOREIGN KEY (test_data_id)
    REFERENCES table_test_data(data_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_param_string (
  param_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  param_string_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  param_string_normal_values VARCHAR(4096) CHARACTER SET utf8,
  param_string_invalid_values VARCHAR(4096) CHARACTER SET utf8,
  PRIMARY KEY(param_string_id),
  UNIQUE KEY param_string_UK_1 (param_string_name)
)
ENGINE=INNODB;

CREATE TABLE table_param_integer (
  param_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  param_integer_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  param_integer_normal_values VARCHAR(4096) CHARACTER SET utf8,
  param_integer_invalid_values VARCHAR(4096) CHARACTER SET utf8,
  PRIMARY KEY(param_integer_id),
  UNIQUE KEY param_integer_UK_1 (param_integer_name)
)
ENGINE=INNODB;

CREATE TABLE table_param_boolean (
  param_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  param_boolean_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(param_boolean_id),
  UNIQUE KEY param_boolean_UK_1 (param_boolean_name)
)
ENGINE=INNODB;

CREATE TABLE table_case_case_data ( 
  case_id INTEGER UNSIGNED NOT NULL, 
  data_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY case_case_data_UK_1(case_id, data_id), 
  INDEX case_case_data_IK_1(case_id), 
  INDEX case_case_data_IK_2(data_id), 
  FOREIGN KEY (case_id) 
    REFERENCES table_case(case_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (data_id) 
    REFERENCES table_case_data(data_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
) ENGINE=INNODB;

CREATE TABLE table_case_param_string (
  case_id INTEGER UNSIGNED NOT NULL,
  param_string_id INTEGER UNSIGNED NOT NULL,
  param_string_value VARCHAR(256) CHARACTER SET utf8,
  UNIQUE KEY case_param_string_UK_1(case_id, param_string_id),
  INDEX case_param_string_IK_1(case_id),
  INDEX case_param_string_IK_2(param_string_id),
  FOREIGN KEY (case_id)
    REFERENCES table_case(case_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_string_id)
    REFERENCES table_param_string(param_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION  
)
ENGINE=INNODB;

CREATE TABLE table_case_param_integer (
  case_id INTEGER UNSIGNED NOT NULL,
  param_integer_id INTEGER UNSIGNED NOT NULL,
  param_integer_value VARCHAR(16) NOT NULL,
  UNIQUE KEY case_param_integer_UK_1(case_id, param_integer_id),
  INDEX case_param_integer_IK_1(case_id),
  INDEX case_param_integer_IK_2(param_integer_id),
  FOREIGN KEY (case_id)
    REFERENCES table_case(case_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_integer_id)
    REFERENCES table_param_integer(param_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION  
)
ENGINE=INNODB;

CREATE TABLE table_case_param_boolean (
  case_id INTEGER UNSIGNED NOT NULL,
  param_boolean_id INTEGER UNSIGNED NOT NULL,
  param_boolean_value BOOL NOT NULL DEFAULT 0,
  UNIQUE KEY case_param_boolean_UK_1(case_id, param_boolean_id),
  INDEX case_param_boolean_IK_1(case_id),
  INDEX case_param_boolean_IK_2(param_boolean_id),
  FOREIGN KEY (case_id)
    REFERENCES table_case(case_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_boolean_id)
    REFERENCES table_param_boolean(param_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION  
)
ENGINE=INNODB;

CREATE TABLE table_sess_agent_status (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  agent_id INTEGER UNSIGNED NOT NULL,
  campaign_session_agent_status INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(campaign_session_id, agent_id),
  INDEX sess_agent_status_IK_1(campaign_session_id),
  INDEX sess_agent_status_IK_2(agent_id),
  FOREIGN KEY (campaign_session_id )
    REFERENCES table_sess(campaign_session_id )
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (agent_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;


CREATE TABLE table_usergroup_user (
  usergroup_id INTEGER UNSIGNED NOT NULL, 
  user_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY usergroup_user_UK_1(usergroup_id, user_id), 
  INDEX usergroup_user_IK_1(usergroup_id), 
  INDEX usergroup_user_IK_2(user_id), 
  FOREIGN KEY (usergroup_id) 
    REFERENCES table_usergroup(usergroup_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (user_id) 
    REFERENCES table_user(user_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB;

CREATE TABLE table_usergroup_folder (
  usergroup_id INTEGER UNSIGNED NOT NULL, 
  folder_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY usergroup_folder_UK_1(usergroup_id, folder_id), 
  INDEX usergroup_folder_IK_1(usergroup_id), 
  INDEX usergroup_folder_IK_2(folder_id), 
  FOREIGN KEY (usergroup_id) 
    REFERENCES table_usergroup(usergroup_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (folder_id) 
    REFERENCES table_folder(folder_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB;

CREATE TABLE table_usergroup_company (
  usergroup_id INTEGER UNSIGNED NOT NULL, 
  company_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY usergroup_company_UK_1(usergroup_id, company_id), 
  INDEX usergroup_company_IK_1(usergroup_id), 
  INDEX usergroup_company_IK_2(company_id), 
  FOREIGN KEY (usergroup_id) 
    REFERENCES table_usergroup(usergroup_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (company_id) 
    REFERENCES table_company(company_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB;

CREATE TABLE table_usergroup_category (
  usergroup_id INTEGER UNSIGNED NOT NULL, 
  category_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY usergroup_category_UK_1(usergroup_id, category_id), 
  INDEX usergroup_category_IK_1(usergroup_id), 
  INDEX usergroup_category_IK_2(category_id), 
  FOREIGN KEY (usergroup_id) 
    REFERENCES table_usergroup(usergroup_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY (category_id) 
    REFERENCES table_category(category_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=INNODB;


CREATE TABLE table_company_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  company_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX company_attach_IK_1(locked_by),
  INDEX company_attach_IK_2(company_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (company_id)
    REFERENCES table_company(company_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_company_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX company_attach_data_IK_1(attachment_id),
  INDEX company_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_company_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sut_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX sut_attach_IK_1(locked_by),
  INDEX sut_attach_IK_2(sut_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sut_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX sut_attach_data_IK_1(attachment_id),
  INDEX sut_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_sut_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_project_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  project_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX project_attach_IK_1(locked_by),
  INDEX project_attach_IK_2(project_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (project_id)
    REFERENCES table_project(project_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_project_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX project_attach_data_IK_1(attachment_id),
  INDEX project_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_project_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_task_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  task_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX task_attach_IK_1(locked_by),
  INDEX task_attach_IK_2(task_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (task_id)
    REFERENCES table_task(task_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_task_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX task_attach_data_IK_1(attachment_id),
  INDEX task_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_task_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sprint_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sprint_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX sprint_attach_IK_1(locked_by),
  INDEX sprint_attach_IK_2(sprint_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sprint_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX sprint_attach_data_IK_1(attachment_id),
  INDEX sprint_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_sprint_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_camp_attach (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT     NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX camp_attach_IK_1(locked_by),
  INDEX camp_attach_IK_2(campaign_id),
  FOREIGN KEY (locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (campaign_id)
    REFERENCES table_camp(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_camp_attach_data (
  data_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB,
  date_submitted DATETIME NULL,
  size_data INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(data_id),
  INDEX camp_attach_data_IK_1(attachment_id),
  INDEX camp_attach_data_IK_2(author_id),
  FOREIGN KEY (attachment_id)
    REFERENCES table_camp_attach(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_cust_string (
  cust_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cust_string_source_type SMALLINT NOT NULL DEFAULT 0,
  cust_string_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  cust_string_mandatory BOOL NOT NULL DEFAULT 0,
  cust_string_default_value VARCHAR(512) CHARACTER SET utf8,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(cust_string_id),
  UNIQUE KEY cust_string_UK_1 (cust_string_source_type, cust_string_name)
)
ENGINE=INNODB;

CREATE TABLE table_cust_integer (
  cust_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cust_integer_source_type SMALLINT NOT NULL DEFAULT 0,
  cust_integer_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  cust_integer_mandatory BOOL NOT NULL DEFAULT 0,
  cust_integer_default_value INTEGER NOT NULL DEFAULT 0,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(cust_integer_id),
  UNIQUE KEY cust_integer_UK_1 (cust_integer_source_type, cust_integer_name)
)
ENGINE=INNODB;

CREATE TABLE table_cust_boolean (
  cust_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cust_boolean_source_type SMALLINT NOT NULL DEFAULT 0,
  cust_boolean_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  cust_boolean_default_value BOOL NOT NULL DEFAULT 0,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(cust_boolean_id),
  UNIQUE KEY cust_boolean_UK_1 (cust_boolean_source_type, cust_boolean_name)
)
ENGINE=INNODB;

CREATE TABLE table_cust_html (
  cust_html_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cust_html_source_type SMALLINT NOT NULL DEFAULT 0,
  cust_html_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  cust_html_mandatory BOOL NOT NULL DEFAULT 0,
  cust_html_default_value TEXT CHARACTER SET utf8,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(cust_html_id),
  UNIQUE KEY cust_html_UK_1 (cust_html_source_type, cust_html_name)
)
ENGINE=INNODB;

CREATE TABLE table_cust_choice (
  cust_choice_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cust_choice_source_type SMALLINT NOT NULL DEFAULT 0,
  cust_choice_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  cust_choice_possible_values VARCHAR(4096) CHARACTER SET utf8 NOT NULL DEFAULT '',
  cust_choice_default_value VARCHAR(4096) CHARACTER SET utf8 NOT NULL DEFAULT '',
  cust_choice_multiple_choices BOOL NOT NULL DEFAULT 0,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(cust_choice_id),
  UNIQUE KEY cust_choice_UK_1 (cust_choice_source_type, cust_choice_name)
)
ENGINE=INNODB;

CREATE TABLE table_cust_string_value (
  cust_string_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value VARCHAR(512) CHARACTER SET utf8,
  INDEX cust_string_value_IK_1(cust_string_id),
  FOREIGN KEY (cust_string_id)
    REFERENCES table_cust_string(cust_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY cust_string_value_UK_1 (cust_string_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_cust_integer_value (
  cust_integer_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value INTEGER NOT NULL,
  INDEX cust_integer_value_IK_1(cust_integer_id),
  FOREIGN KEY (cust_integer_id)
    REFERENCES table_cust_integer(cust_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY cust_integer_value_UK_1 (cust_integer_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_cust_boolean_value (
  cust_boolean_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value BOOLEAN NOT NULL,
  INDEX cust_boolean_value_IK_1(cust_boolean_id),
  FOREIGN KEY (cust_boolean_id)
    REFERENCES table_cust_boolean(cust_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY cust_boolean_value_UK_1 (cust_boolean_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_cust_html_value (
  cust_html_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8,
  INDEX cust_html_value_IK_1(cust_html_id),
  FOREIGN KEY (cust_html_id)
    REFERENCES table_cust_html(cust_html_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY cust_html_value_UK_1 (cust_html_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_cust_choice_value (
  cust_choice_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value VARCHAR(64) CHARACTER SET utf8,
  INDEX cust_choice_value_IK_1(cust_choice_id),
  FOREIGN KEY (cust_choice_id)
    REFERENCES table_cust_choice(cust_choice_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY cust_choice_value_UK_1 (cust_choice_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_req_generic (
  requirement_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  external_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(requirement_id),
  INDEX req_generic_IK_1(folder_id),
  FOREIGN KEY (folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_req_test (
  requirement_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX req_test_IK_1(requirement_id),
  INDEX req_test_IK_2(test_id),
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_def_int_ccemails (
  defect_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX def_int_ccemails_IK_1(defect_id),
  INDEX def_int_ccemails_IK_2(user_id),
  FOREIGN KEY (defect_id)
    REFERENCES table_def_int(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_search (
  search_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  search_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  type TINYINT NOT NULL,
  search_data MEDIUMTEXT CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(search_id)
)
ENGINE=INNODB;

CREATE TABLE table_search_cust_string (
  search_id INTEGER UNSIGNED NOT NULL,
  cust_string_id INTEGER UNSIGNED NOT NULL,
  value VARCHAR(512) CHARACTER SET utf8,
  INDEX search_cust_string_IK_1(search_id),
  INDEX search_cust_string_IK_2(cust_string_id),
  FOREIGN KEY (search_id)
    REFERENCES table_search(search_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (cust_string_id)
    REFERENCES table_cust_string(cust_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY search_cust_string_UK_1 (search_id, cust_string_id)
)
ENGINE=INNODB;

CREATE TABLE table_search_cust_integer (
  search_id INTEGER UNSIGNED NOT NULL,
  cust_integer_id INTEGER UNSIGNED NOT NULL,
  value INTEGER NOT NULL,
  INDEX search_cust_integer_IK_1(search_id),
  INDEX search_cust_integer_IK_2(cust_integer_id),
  FOREIGN KEY (search_id)
    REFERENCES table_search(search_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (cust_integer_id)
    REFERENCES table_cust_integer(cust_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY search_cust_integer_UK_1 (search_id, cust_integer_id)
)
ENGINE=INNODB;

CREATE TABLE table_search_cust_boolean (
  search_id INTEGER UNSIGNED NOT NULL,
  cust_boolean_id INTEGER UNSIGNED NOT NULL,
  value BOOLEAN NOT NULL,
  INDEX search_cust_boolean_IK_1(search_id),
  INDEX search_cust_boolean_IK_2(cust_boolean_id),
  FOREIGN KEY (search_id)
    REFERENCES table_search(search_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (cust_boolean_id)
    REFERENCES table_cust_boolean(cust_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY search_cust_boolean_UK_1 (search_id, cust_boolean_id)
)
ENGINE=INNODB;

CREATE TABLE table_search_cust_html (
  search_id INTEGER UNSIGNED NOT NULL,
  cust_html_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8,
  INDEX search_cust_html_IK_1(search_id),
  INDEX search_cust_html_IK_2(cust_html_id),
  FOREIGN KEY (search_id)
    REFERENCES table_search(search_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (cust_html_id)
    REFERENCES table_cust_html(cust_html_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY search_cust_html_UK_1 (search_id, cust_html_id)
)
ENGINE=INNODB;

CREATE TABLE table_search_cust_choice (
  search_id INTEGER UNSIGNED NOT NULL,
  cust_choice_id INTEGER UNSIGNED NOT NULL,
  value VARCHAR(64) CHARACTER SET utf8,
  INDEX search_cust_choice_IK_1(search_id),
  INDEX search_cust_choice_IK_2(cust_choice_id),
  FOREIGN KEY (search_id)
    REFERENCES table_search(search_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (cust_choice_id)
    REFERENCES table_cust_choice(cust_choice_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY search_cust_choice_UK_1 (search_id, cust_choice_id)
)
ENGINE=INNODB;

CREATE TABLE table_sess_param_string (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  param_string_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8,
  INDEX sess_param_string_IK_1(campaign_session_id),
  INDEX sess_param_string_IK_2(param_string_id),
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_string_id)
    REFERENCES table_param_string(param_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sess_param_boolean (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  param_boolean_id INTEGER UNSIGNED NOT NULL,
  value BOOL NOT NULL DEFAULT 0,
  INDEX sess_param_boolean_IK_1(campaign_session_id),
  INDEX sess_param_boolean_IK_2(param_boolean_id),
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_boolean_id)
    REFERENCES table_param_boolean(param_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sess_param_integer (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  param_integer_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX sess_param_integer_IK_1(campaign_session_id),
  INDEX sess_param_integer_IK_2(param_integer_id),
  FOREIGN KEY (campaign_session_id)
    REFERENCES table_sess(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_integer_id)
    REFERENCES table_param_integer(param_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;




CREATE TABLE table_sch_attr_string (
  schedule_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8,
  INDEX sch_attr_string_IK_1(schedule_id),
  INDEX sch_attr_string_IK_2(test_id),
  INDEX sch_attr_string_IK_3(attr_string_id),
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sch_attr_boolean (
  schedule_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  value BOOL NOT NULL DEFAULT 0,
  INDEX sch_attr_boolean_IK_1(schedule_id),
  INDEX sch_attr_boolean_IK_2(test_id),
  INDEX sch_attr_boolean_IK_3(attr_boolean_id),
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sch_attr_integer (
  schedule_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX sch_attr_integer_IK_1(schedule_id),
  INDEX sch_attr_integer_IK_2(test_id),
  INDEX sch_attr_integer_IK_3(attr_integer_id),
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;






CREATE TABLE table_sch_param_string (
  schedule_id INTEGER UNSIGNED NOT NULL,
  param_string_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8,
  INDEX sch_param_string_IK_1(schedule_id),
  INDEX sch_param_string_IK_2(param_string_id),
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_string_id)
    REFERENCES table_param_string(param_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sch_param_boolean (
  schedule_id INTEGER UNSIGNED NOT NULL,
  param_boolean_id INTEGER UNSIGNED NOT NULL,
  value BOOL NOT NULL DEFAULT 0,
  INDEX sch_param_boolean_IK_1(schedule_id),
  INDEX sch_param_boolean_IK_2(param_boolean_id),
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_boolean_id)
    REFERENCES table_param_boolean(param_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_sch_param_integer (
  schedule_id INTEGER UNSIGNED NOT NULL,
  param_integer_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX sch_param_integer_IK_1(schedule_id),
  INDEX sch_param_integer_IK_2(param_integer_id),
  FOREIGN KEY (schedule_id)
    REFERENCES table_sch(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY (param_integer_id)
    REFERENCES table_param_integer(param_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;
