UPDATE table_version SET version_number = '24' WHERE version_id = '1';

ALTER TABLE table_testcase ADD UNIQUE KEY(test_id, testcase_index, testcase_name);

CREATE TABLE table_monitoring_configuration (
  monitoring_configuration_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  monitoring_configuration_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  monitoring_configuration_content TEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(monitoring_configuration_id),
  INDEX monitoring_configuration_id_FKIndex1(monitoring_configuration_id)
)
ENGINE=InnoDB;

ALTER TABLE table_campaign_session ADD monitoring_id INTEGER UNSIGNED;
ALTER TABLE table_campaign_session ADD INDEX campaign_session_FKIndex6(monitoring_id);
ALTER TABLE table_campaign_session ADD FOREIGN KEY(monitoring_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION;
ALTER TABLE table_campaign_session ADD monitoring_configuration_id INTEGER UNSIGNED;
ALTER TABLE table_campaign_session ADD INDEX campaign_session_FKIndex7(monitoring_configuration_id);
ALTER TABLE table_campaign_session ADD FOREIGN KEY(monitoring_configuration_id)
    REFERENCES table_monitoring_configuration(monitoring_configuration_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION;
      
ALTER TABLE table_schedule ADD monitoring_id INTEGER UNSIGNED;
ALTER TABLE table_schedule ADD INDEX table_schedule_FKIndex4(sut_id);
ALTER TABLE table_schedule ADD INDEX table_schedule_FKIndex5(monitoring_id);
ALTER TABLE table_schedule ADD FOREIGN KEY(monitoring_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION;
ALTER TABLE table_schedule ADD monitoring_configuration_id INTEGER UNSIGNED;
ALTER TABLE table_schedule ADD INDEX table_schedule_FKIndex6(monitoring_configuration_id);
ALTER TABLE table_schedule ADD FOREIGN KEY(monitoring_configuration_id)
    REFERENCES table_monitoring_configuration(monitoring_configuration_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION;
      
      
            
CREATE TABLE table_monitor ( 
  monitor_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  campaign_session_id INTEGER UNSIGNED NOT NULL, 
  monitored_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(monitor_id),
  UNIQUE KEY(campaign_session_id, monitored_id), 
  INDEX monitoring_FKIndex1(campaign_session_id), 
  INDEX monitoring_FKIndex2(monitored_id), 
  FOREIGN KEY(campaign_session_id) 
    REFERENCES table_campaign_session(campaign_session_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(monitored_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB; 

CREATE TABLE table_monitored_results ( 
  monitor_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  timestamp BIGINT UNSIGNED NOT NULL DEFAULT 0,
  class VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  subclass VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  value INTEGER NOT NULL DEFAULT 0, 
  INDEX monitored_results_FKIndex1(monitor_id),
  FOREIGN KEY(monitor_id) 
    REFERENCES table_monitor(monitor_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION     
)
ENGINE=InnoDB; 

CREATE TABLE table_schedule_monitored ( 
  schedule_id INTEGER UNSIGNED NOT NULL, 
  monitored_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY(schedule_id, monitored_id), 
  INDEX schedule_monitored_FKIndex1(schedule_id), 
  INDEX schedule_monitored_FKIndex2(monitored_id), 
  FOREIGN KEY(schedule_id) 
    REFERENCES table_schedule(schedule_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(monitored_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB;  

ALTER TABLE table_filter MODIFY filter_description TEXT CHARACTER SET utf8 NULL;
ALTER TABLE table_filter MODIFY filter_content LONGTEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_testcase MODIFY testcase_steps TEXT CHARACTER SET utf8 NULL;
ALTER TABLE table_testcase MODIFY testcase_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_testcase MODIFY testcase_description TEXT CHARACTER SET utf8 NULL;
ALTER TABLE table_testcase MODIFY additional_info TEXT CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_change MODIFY information VARCHAR(255) CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_company MODIFY company_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_category MODIFY category_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_category MODIFY category_envDesc TEXT CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_category MODIFY category_jarName VARCHAR(64) CHARACTER SET utf8 NULL;

ALTER TABLE table_attr_string MODIFY attr_string_name VARCHAR(60) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_attr_integer MODIFY attr_integer_name VARCHAR(60) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_attr_boolean MODIFY attr_boolean_name VARCHAR(60) CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_folder MODIFY folder_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_project MODIFY project_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_project MODIFY project_description TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_sut MODIFY sut_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_sut MODIFY sut_version VARCHAR(64) CHARACTER SET utf8 NULL;

ALTER TABLE table_agent MODIFY agent_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_agent MODIFY agent_os VARCHAR(64) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_agent MODIFY agent_description TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_defect_integrated MODIFY defect_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_defect_integrated MODIFY defect_description TEXT CHARACTER SET utf8 NULL;
ALTER TABLE table_defect_integrated MODIFY step_to_reproduce TEXT CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_defect_integrated MODIFY fix_description TEXT CHARACTER SET utf8 NULL;
ALTER TABLE table_defect_integrated MODIFY fix_patches VARCHAR(64) CHARACTER SET utf8 NULL;
ALTER TABLE table_defect_integrated MODIFY fix_target_version VARCHAR(32) CHARACTER SET utf8 NULL;

ALTER TABLE table_requirement MODIFY requirement_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_requirement MODIFY requirement_description TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_campaign MODIFY campaign_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_specification MODIFY specification_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_specification MODIFY specification_description TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_test MODIFY test_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_test MODIFY test_description LONGTEXT CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_test MODIFY test_prerequisites TEXT CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_test MODIFY additional_info TEXT CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_schedule MODIFY schedule_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_schedule MODIFY schedule_description TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_campaign_session MODIFY campaign_session_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_campaign_session MODIFY introduction TEXT CHARACTER SET utf8 NULL;
ALTER TABLE table_campaign_session MODIFY conclusion TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_test_attr_string MODIFY test_attr_string_value TEXT CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_test_attr_integer MODIFY test_attr_integer_value TEXT CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_testcase_execution MODIFY testcase_execution_message MEDIUMTEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_defect_stat MODIFY container VARCHAR(255) CHARACTER SET utf8 NULL;
ALTER TABLE table_defect_stat MODIFY stat MEDIUMTEXT CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_platform MODIFY platform_name VARCHAR(32) CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_os MODIFY os_name VARCHAR(32) CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_configuration MODIFY jar_name VARCHAR(64) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_configuration MODIFY configuration_name VARCHAR(64) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_configuration MODIFY configuration_content TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_task MODIFY task_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_task MODIFY task_description TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_sprint MODIFY sprint_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_sprint MODIFY sprint_description TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_sprint_stat MODIFY stat MEDIUMTEXT CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_campaign_session_attribute_integer MODIFY value TEXT CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_campaign_session_attribute_string MODIFY value TEXT CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_absence_type MODIFY absence_type_name VARCHAR(64) CHARACTER SET utf8 NOT NULL;

ALTER TABLE table_absence MODIFY comment TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_holiday MODIFY comment TEXT CHARACTER SET utf8 NULL;

ALTER TABLE table_weekend MODIFY days VARCHAR(14) CHARACTER SET utf8 ;

ALTER TABLE table_testcase_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_test_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_folder_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_category_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_testcase_execution_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_defect_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_campaign_session_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_requirement_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
ALTER TABLE table_specification_attachment MODIFY attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL;
