UPDATE table_version SET version_number = '52' WHERE version_id = '1';

ALTER TABLE table_case_data ADD editor_type NUMBER(3,0) DEFAULT '1' NOT NULL;
ALTER TABLE table_case_data DROP COLUMN testcase_useDescAsTestplan;


CREATE SEQUENCE  SEQ_sqlreport MINVALUE 1 MAXVALUE 999999999999999999999999 INCREMENT BY 1  NOCYCLE;
CREATE SEQUENCE  SEQ_sqlreport_data MINVALUE 1 MAXVALUE 999999999999999999999999 INCREMENT BY 1  NOCYCLE;


CREATE TABLE table_sqlreport (
  sqlreport_id NUMBER(10,0) NOT NULL,
  folder_id NUMBER(10,0) NOT NULL,
  sqlreport_name VARCHAR2(128 CHAR) NOT NULL);
ALTER TABLE table_sqlreport ADD CONSTRAINT PRIMARY_87 PRIMARY KEY (sqlreport_id) ENABLE;
CREATE INDEX sqlreport_IK_1 ON table_sqlreport (folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sqlreport TO PUBLIC;
  
  
CREATE TABLE table_sqlreport_data ( 
  data_id NUMBER(10,0) NOT NULL,
  sqlreport_id NUMBER(10,0) NOT NULL, 
  query CLOB, 
  date_submitted DATE, 
  revision NUMBER(10,0) DEFAULT '1' NOT NULL);
ALTER TABLE table_sqlreport_data ADD CONSTRAINT PRIMARY_88 PRIMARY KEY (data_id) ENABLE;
CREATE UNIQUE INDEX sqlreport_data_UK_1 ON table_sqlreport_data (sqlreport_id, revision);
CREATE INDEX sqlreport_data_IK_1 ON table_sqlreport_data (sqlreport_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sqlreport_data TO PUBLIC;


ALTER TABLE table_sqlreport ADD CONSTRAINT table_sqlreport_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder(folder_id) ON DELETE CASCADE ENABLE;
ALTER TABLE table_sqlreport_data ADD CONSTRAINT table_sqlreport_data_ibfk_1 FOREIGN KEY (sqlreport_id) REFERENCES table_sqlreport(sqlreport_id) ON DELETE CASCADE ENABLE;


CREATE OR REPLACE TRIGGER TRIG_sqlreport BEFORE INSERT OR UPDATE ON table_sqlreport FOR EACH ROW
DECLARE 
v_newVal NUMBER(12) := 0;
v_incval NUMBER(12) := 0;
BEGIN
  IF INSERTING AND :new.sqlreport_id IS NULL THEN
    SELECT  SEQ_sqlreport.NEXTVAL INTO v_newVal FROM DUAL;
    IF v_newVal = 1 THEN 
      SELECT NVL(max(sqlreport_id),0) INTO v_newVal FROM table_sqlreport;
      v_newVal := v_newVal + 1;
      LOOP
           EXIT WHEN v_incval>=v_newVal;
           SELECT SEQ_sqlreport.nextval INTO v_incval FROM dual;
      END LOOP;
    END IF;
   :new.sqlreport_id := v_newVal;
  END IF;
END;
/
CREATE OR REPLACE TRIGGER TRIG_sqlreport_data BEFORE INSERT OR UPDATE ON table_sqlreport_data FOR EACH ROW
DECLARE 
v_newVal NUMBER(12) := 0;
v_incval NUMBER(12) := 0;
BEGIN
  IF INSERTING AND :new.data_id IS NULL THEN
    SELECT  SEQ_sqlreport_data.NEXTVAL INTO v_newVal FROM DUAL;
    IF v_newVal = 1 THEN 
      SELECT NVL(max(data_id),0) INTO v_newVal FROM table_sqlreport_data;
      v_newVal := v_newVal + 1;
      LOOP
           EXIT WHEN v_incval>=v_newVal;
           SELECT SEQ_sqlreport_data.nextval INTO v_incval FROM dual;
      END LOOP;
    END IF;
   :new.data_id := v_newVal;
  END IF;
END;
/

INSERT INTO table_folder VALUES (12, 12, 'na', 1, 1, 1, NULL);
INSERT INTO table_folder VALUES (28, 12, 'My reports', 1, 1, 1, 'This is a folder containing some SQL reports');

INSERT INTO table_sqlreport VALUES(100, 28, 'Longest tests to execute');
INSERT INTO table_sqlreport_data VALUES(100, 100, 'SELECT ''[T_'' || test_id || '']'' AS Id, test_name AS Name, test_estimatedTime AS Milliseconds
FROM table_test
ORDER BY test_estimatedTime DESC', to_date('2013-03-04 00:00:01', 'yyyy-mm-dd hh24:mi:ss'), 1);

INSERT INTO table_sqlreport VALUES(99, 28, 'Tests authored by');
INSERT INTO table_sqlreport_data VALUES(99, 99, 'SELECT ''[T_'' || test_id || '']'' AS Id, test_name AS Name, user_name AS Author
FROM table_test, table_user
WHERE table_test.author_id = table_user.user_id
AND user_name = ''admin''', to_date('2013-03-04 00:00:01', 'yyyy-mm-dd hh24:mi:ss'), 1);

INSERT INTO table_sqlreport VALUES(98, 28, 'Tests developed by');
INSERT INTO table_sqlreport_data VALUES(98, 98, 'SELECT ''[T_'' || test_id || '']'' AS Id, test_name AS Name, user_name AS Author
FROM table_test, table_user
WHERE table_test.developer_id = table_user.user_id
AND user_name = ''admin''', to_date('2013-03-04 00:00:01', 'yyyy-mm-dd hh24:mi:ss'), 1);







