<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="reports/@codebase" />
  <xsl:variable name="bugtrackingType" select="reports/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="reports/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="reports/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/reportHTML_Lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
    
	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="nbCategory"            select="count(reports/campaignsession/category[count(descendant-or-self::test)>0])" />
        <xsl:variable name="graphInReportsEnabled" select="reports/@graphInReportsEnabled" />
        <xsl:variable name="documentDate"          select="reports/@date" />
        <xsl:variable name="documentAuthor"        select="reports/@author" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
              <td valign="top" align="right">
                <table>
                  <tr><td class="table_label" align="right">#report.Start_date#:</td><td class="table_value" align="left"><xsl:value-of disable-output-escaping="yes" select="reports/campaignsession/@start_date"/></td></tr>
                  <tr><td class="table_label" align="right">#report.Stop_date#:</td><td class="table_value" align="left"><xsl:value-of disable-output-escaping="yes" select="reports/campaignsession/@stop_date"/></td></tr>
                </table>
              </td>
            </tr>
          </table>
          <br/>

          <span class="report_title">#report.Campaign_session_report#</span><br/>
          <span class="report_title"><i>Raw Results - <xsl:value-of disable-output-escaping="yes" select="reports/campaignsession/@name"/></i></span><br/>
        </div>
        <br/><br/><br/><br/>

        <xsl:for-each select="reports/campaignsession">

          <xsl:variable name="introduction" select="introduction" />
          <xsl:if test="string-length($introduction)>0">
            <a name="_introduction"/>
            <h1>#report.Introduction#</h1>
            <p><xsl:value-of disable-output-escaping="yes" select="introduction"/></p>
          </xsl:if>

          <!-- Attachments -->
          <xsl:call-template name="generateAttachments">
            <xsl:with-param name="parentType"     select="'CS_'"/>
            <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
          </xsl:call-template>

          <a name="_conf"/>
          <h1>#report.Configuration#</h1>
          <table border="0">
            <tr>
                <td class="table_data_subsubheader">#report.Sut#</td>
                <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="sut/@name"/>&#160;<xsl:value-of disable-output-escaping="yes" select="sut/@version"/></td>
            </tr>
            <tr>
                <td class="table_data_subsubheader">#report.Operator#</td>
                <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="operator/@name"/></td>
            </tr>
            <tr>
                <td class="table_data_subsubheader">#report.Agent#</td>
                <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="agent/@name"/>&#160;<xsl:value-of disable-output-escaping="yes" select="agent/@os"/></td>
            </tr>
          </table>

          <xsl:for-each select="configurations/configuration">
            <h2><xsl:value-of select="@categoryName" /> (<xsl:value-of select="@jarName" />: <xsl:value-of select="@name" />)</h2>
            <xsl:for-each select="object[@type='root']/form">
              <table border="0" width="100%">
                <tr>
                  <td colspan="2" class="table_data_subheader"><xsl:value-of select="@name" /></td>
                </tr>
                <xsl:call-template name="conf"/>
              </table>
              <br/>
            </xsl:for-each>
          </xsl:for-each>

          <a name="_details"/>
          <h1>#report.Details#</h1>
          <!-- ******************* tests DETAILS *************************** -->
          <xsl:if test="$nbCategory > 0">
            <xsl:for-each select="category[count(descendant-or-self::test)>0]">
              <xsl:variable name="categoryName" select="@name" />
              <xsl:variable name="nbTestsInThisCategory" select="count(descendant::test)" />

              <!-- Categories -->
              <h2>
                <img src="#images#/IconCategory.gif"/>&#160;
                <xsl:value-of disable-output-escaping="yes" select="$categoryName" />&#160;
              </h2>

              <!-- Attachments -->
              <xsl:call-template name="generateAttachments">
                <xsl:with-param name="parentType"     select="'CT_'"/>
                <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
              </xsl:call-template>

              <!-- Folders -->
              <xsl:for-each select="folder[count(descendant::test) > 0]"> <!-- recursive call to display folders -->
                  <xsl:call-template name="generateDetailsFolder">
                    <xsl:with-param name="parentName" select="$categoryName"/>
                  </xsl:call-template>
              </xsl:for-each>

            </xsl:for-each>
          </xsl:if>


          <xsl:variable name="nbDefects" select="count(descendant::defect)" />
          <xsl:if test="$nbDefects > 0">
            <a name="_defects"/>
            <h1>#report.Defects#</h1>

            <!-- ******************* DEFECTS *************************** -->

            <!--
            A defect can be associated to several tests.
            How to return unique nodes?
            The method is a simplified version of the so-called Muenchian method.
            The idea is that the xsl:key returns node sets that match each unique
            value of the key, in this case the defect.
            -->
            <xsl:key name='defectKey' match='defect' use='@id'/>

            <!--
            Then, we do a for-each, but only on those nodes that match the first
            node returned by the unique keys.
            -->
            <xsl:call-template name="generateDefectsDetails">
  			      <xsl:with-param name="nodeSet" select="descendant::defect[generate-id()=generate-id(key('defectKey',@id)[1])]"/>
    		    </xsl:call-template>
          </xsl:if>

          <xsl:variable name="conclusion" select="conclusion" />
          <xsl:if test="string-length($conclusion)>0">
            <a name="_conclusion"/>
            <h1>#report.Conclusion#</h1>
            <p><xsl:value-of disable-output-escaping="yes" select="conclusion"/></p>
          </xsl:if>
        </xsl:for-each>
        <br/><br/><br/><br/>
        
        <a name="_tbd"/>
        <xsl:call-template name="generateTBD"/>
        <br/><br/><br/>
       
        <a name="_abbr"/>
        <xsl:call-template name="generateABBR"/>
        <br/><br/><br/>        
      </body>
    </html>

  </xsl:template>




















  <xsl:template name="generateDetailsFolder">
    <xsl:param name="parentName"/>

    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="folderDescription" select="description" />

    <xsl:if test="count(test) > 0">
      <h3>Reference: <xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>
      <!-- folder description -->
      <p><xsl:value-of disable-output-escaping="yes" select="$folderDescription" /></p>

      <xsl:call-template name="generateAttachments">
        <xsl:with-param name="parentType" select="'FL_'"/>
        <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
      </xsl:call-template>

      <xsl:call-template name="generateTestsExecutionDetails">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>
    </xsl:if>

    <!-- Recursivity -->
    <xsl:for-each select="folder">
      <xsl:if test="count(descendant::test) > 0">
        <xsl:call-template name="generateDetailsFolder">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateTestsExecutionDetails">
      <xsl:for-each select="test">
        <xsl:variable name="testId" select="@id" />
        <xsl:variable name="testName" select="@name" />
        <xsl:variable name="testStatus" select="@status" />

        <!-- Test -->
        <table width="100%">
          <!--
          <tr>
            <td class="table_data_header" width="85%">#report.Tests#</td>
            <td class="table_data_header" width="15%">#report.Result#</td>
          </tr>
          -->
          <tr>
            <td class="table_data_subheader_bottom_align">
              <h4 class="no_margin">
                <img src="#images#/IconTest.gif"/>&#160;
                [T_<xsl:value-of select="$testId" />] <xsl:value-of select="$testName" />
              </h4>
            </td>
            <td class="table_data_subheader_bottom_align"  width="18%" valign="bottom"> <!-- so that all test results are aligned -->
              <b><xsl:call-template name="statusToIconAndString"><xsl:with-param name="status" select="$testStatus"/></xsl:call-template></b>
            </td>
          </tr>
        </table>
        <br/><br/>
        
        
        <!-- Test cases -->
          <!-- ******************* TESTCASES *************************** -->
          <xsl:for-each select="testcase">
            <!--<xsl:sort select="@index" />-->

            <xsl:variable name="testcaseId"      select="@id" />
            <xsl:variable name="testcaseIndex"   select="@index" />
            <xsl:variable name="testcaseName"    select="@name" />
            <xsl:variable name="testcaseStatus"  select="@status" />

            <table border="0" width="100%">
              <tr>
                <td width="30px">&#160;&#160;&#160;&#160;&#160;&#160;</td> <!-- indentation - width attr not interpreted by MSWord but is usefull for HTML -->
                <td class="table_data_subsubheader" width="5%">#report.Index#</td>
                <td class="table_data_subsubheader" width="20%">#report.Name#</td>
                <td class="table_data_subsubheader" width="60%">#report.Message#</td>
                <td class="table_data_subsubheader" width="15%">#report.Result#</td>
              </tr>

              <tr>
                <td/>  <!-- indentation -->
                <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$testcaseIndex" /></td>
  
                <td class="table_data_content">
                  <h5 class="no_margin">
                    [TC_<xsl:value-of disable-output-escaping="yes" select="$testcaseId" />] <xsl:value-of disable-output-escaping="yes" select="$testcaseName" />
                  </h5>
                </td>
  
                <td class="table_data_content">
                  <xsl:call-template name="testcaseMessage"/>
                  <br/>
                  <!-- Attachments -->
                  <xsl:call-template name="generateAttachments">
                    <xsl:with-param name="parentType"     select="'TC_'"/>
                    <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
                  </xsl:call-template>
                </td>
  
                <td class="table_data_content">
                  <xsl:call-template name="statusToIconAndString">
                    <xsl:with-param name="status" select="$testcaseStatus"/>
                  </xsl:call-template>
                </td>
              </tr>
              
            </table>
            <br/><br/>
            
            
          </xsl:for-each> <!-- testcases -->
        <br/>

        <xsl:variable name="nbDefects" select="count(defect)" />
        <xsl:if test="$nbDefects > 0">
            <!-- ******************* DEFECTS *************************** -->
            <table width="100%">
              <xsl:call-template name="generateShortDefectHeader">
              </xsl:call-template>
              <xsl:for-each select="defect">
                 <xsl:call-template name="generateShortDefect">
                 </xsl:call-template>
              </xsl:for-each>
            </table>
        </xsl:if>
        <!--
        <xsl:if test="$nbDefects = 0">
           #defect.No_defect_available#
        </xsl:if>
        -->
      </xsl:for-each>
  </xsl:template>





</xsl:stylesheet>