<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="reports/@codebase" />
  <xsl:variable name="bugtrackingType" select="reports/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="reports/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="reports/@specificationInLifecycle" />

	<xsl:template match="/">
		<xsl:variable name="sessionName"   select="reports/campaignsession/@name" />
		<xsl:variable name="operatorName"  select="reports/campaignsession/operator/@name" />
		<xsl:variable name="categoryName"  select="reports/campaignsession/category/@name" />

		<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
		<head>
		</head>
		<body>
			<table border="1">
				<tr>
					<td>Test</td><td>Test-case</td>
					<td>
						<xsl:value-of disable-output-escaping="yes" select="$sessionName"/>
						<br/>
						by:<xsl:value-of disable-output-escaping="yes" select="$operatorName"/>
					</td>
					<td>folders</td>
				</tr>
				
				<xsl:apply-templates>
					<xsl:with-param name="parentName" select="" />
				</xsl:apply-templates>
			</table>
		</body>
		</html>
	</xsl:template>

<!-- ******************* campaignsession *************************** -->
<xsl:template match="campaignsession">
	<xsl:param name="parentName" />
	<xsl:apply-templates select="category">
		<xsl:with-param name="parentName" select="$parentName"/>
	</xsl:apply-templates>
</xsl:template>

<!-- ******************* category *************************** -->
<xsl:template match="category">
	<xsl:param name="parentName" />
	<xsl:apply-templates select="folder">
		<xsl:with-param name="parentName" select="@name"/>
	</xsl:apply-templates>
</xsl:template>


<!-- ******************* folder *************************** -->
<xsl:template match="folder">
	<xsl:param name="parentName" />
	<xsl:variable name="folderName" select="@name" />
	<xsl:variable name="pathName" select="concat($parentName, '|', $folderName)" />
	<xsl:apply-templates select="test">
		<xsl:with-param name="parentName" select="$pathName"/>  
	</xsl:apply-templates>
	<xsl:apply-templates select="folder">
		<xsl:with-param name="parentName" select="$pathName"/>
	</xsl:apply-templates>
</xsl:template>

<!-- ******************* test *************************** -->
<xsl:template match="test">
	<xsl:param name="parentName" />
	<tr>
		<td><xsl:value-of disable-output-escaping="yes" select="@name"/></td>
		<td><xsl:text>&#xa0;</xsl:text></td>
		<td><xsl:text>&#xa0;</xsl:text></td>
		<td><xsl:value-of disable-output-escaping="yes" select="$parentName"/></td>
	</tr>
	<xsl:apply-templates select="testcase">
		<xsl:with-param name="pathName" select="$parentName"/>  
		<xsl:with-param name="testName" select="@name"/>  
	</xsl:apply-templates>
</xsl:template>

<!-- ******************* test-case *************************** -->
<xsl:template match="testcase">
	<xsl:param name="pathName" />
	<xsl:param name="testName" />
	<tr>
		<td><xsl:text>&#xa0;</xsl:text></td>
		<td><xsl:value-of disable-output-escaping="yes" select="@name"/></td>
		<xsl:call-template name="statusToString"><xsl:with-param name="status" select="@status"/></xsl:call-template>		
		<td><xsl:text>&#xa0;</xsl:text></td>
	</tr>
</xsl:template>

<!-- ******************* status to string *************************** -->
	<xsl:template name="statusToString">
		<xsl:param name="status"/>
		<xsl:if test="$status='1'"><td style="background-color:green">#report.Success#</td></xsl:if>				
		<xsl:if test="$status='2'"><td style="background-color:red">#report.Failure#</td></xsl:if>				
		<xsl:if test="$status='0'"><td>#report.Not_executed#</td></xsl:if>				
		<xsl:if test="$status='6'"><td>#report.Unknown#</td></xsl:if>				
		<xsl:if test="$status='3'"><td>#report.Relative#</td></xsl:if>
	</xsl:template>


</xsl:stylesheet>